# Acknowledgement

This is a list of modules and snipped of codes taken from the wonderful
python open-source community. In order of inclusion into pulsar:

* Python Http parser originally from [http-parser](https://github.com/benoitc/http-parser)
```
2011-2013 (c) Benoît Chesneau <benoitc@e-engura.org>

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so...
```
* Autoreload utility [d6f0abf](https://github.com/quantmind/pulsar/commit/d6f0abf99bb4f539101f3badadba3d027eb1e295)
```
# Autoreloading launcher.
# Borrowed from Peter Hunt and the CherryPy project (http://www.cherrypy.org).
# Some taken from Ian Bicking's Paste (http://pythonpaste.org/).
#
# Portions copyright (c) 2004, CherryPy Team (team@cherrypy.org)
# All rights reserved.
```
* ``parse_header_links`` from [requests][]
```
Copyright 2016 Kenneth Reitz

   Licensed under the Apache License, Version 2.0 (the "License")
```



[requests]: http://docs.python-requests.org/en/master/
